import onetouchlite.tools as tools


tools.prints(1, style='color:bright_blue;', display=True)

tools.prints(1, style='color:bright_blue;bold:True', display=True)

tools.prints(1, style='color:bright_blue;bold:False', display=True)

tools.printc(2, color="bright_blue", display=True)

tools.printc(2, color="bright_blue", display=True)

tools.printc(2, color="bright_blue", display=True)
